{ lib, pkgs, config, myconfig,  ... }:
let
  adminer = pkgs.callPackage ../commons/adminer.nix {};

  tellesflorian_dev  = pkgs.callPackage ./tellesflorian.nix {
    inherit (pkgs.webapps) tellesflorian;
    config = myconfig.env.websites.tellesflorian.integration;
  };

  cfg = config.services.myWebsites.TellesFlorian;
in {
  options.services.myWebsites.TellesFlorian = {
    integration = {
      enable = lib.mkEnableOption "enable Florian Telles's website in integration";
    };
  };

  config = lib.mkIf cfg.integration.enable {
    secrets.keys = tellesflorian_dev.keys;
    services.myPhpfpm.preStart.tellesflorian_dev = tellesflorian_dev.phpFpm.preStart;
    services.myPhpfpm.serviceDependencies.tellesflorian_dev = tellesflorian_dev.phpFpm.serviceDeps;
    services.myPhpfpm.poolConfigs.tellesflorian_dev = tellesflorian_dev.phpFpm.pool;
    system.activationScripts.tellesflorian_dev = tellesflorian_dev.activationScript;
    system.extraSystemBuilderCmds = ''
      mkdir -p $out/webapps
      ln -s ${tellesflorian_dev.app.webRoot} $out/webapps/${tellesflorian_dev.apache.webappName}
      '';
    services.websites.integration.modules = adminer.apache.modules ++ tellesflorian_dev.apache.modules;
    services.websites.integration.vhostConfs.tellesflorian = {
      certName    = "eldiron";
      addToCerts  = true;
      hosts       = ["app.tellesflorian.com" ];
      root        = tellesflorian_dev.apache.root;
      extraConfig = [
        tellesflorian_dev.apache.vhostConf
        adminer.apache.vhostConf
      ];
    };
  };
}
